@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use vars qw( $VERSION @EXPORT @EXPORT_OK @ISA $CurrentPackage @IncludeLibs $ScanFileRE );
 
-$VERSION   = '1.08';
+$VERSION   = '1.16';
 @EXPORT    = qw( scan_deps scan_deps_runtime );
 @EXPORT_OK = qw( scan_line scan_chunk add_deps scan_deps_runtime path_to_inc_name );
 
@@ -26,7 +26,7 @@ use File::Temp ();
 use File::Spec ();
 use File::Basename ();
 use FileHandle;
-use Module::Build::ModuleInfo;
+use Module::Metadata;
 
 $ScanFileRE = qr/(?:^|\\|\/)(?:[^.]*|.*\.(?i:p[ml]|t|al))$/;
 
@@ -117,8 +117,8 @@ If C<$compile> or C<$execute> is true, runs C<files> in either
 compile-only or normal mode, then inspects their C<%INC> after
 termination to determine additional runtime dependencies.
 
-If C<$execute> is an array reference, runs the files contained
-in it instead of C<@files>.
+If C<$execute> is an array reference, passes C<@$execute>
+as arguments to each file in C<@files> when it is run.
 
 If performance of the scanning process is a concern, C<cache_file> can be
 set to a filename. The scanning results will be cached and written to the
@@ -200,7 +200,7 @@ C<$Module::ScanDeps::ScanFileRE = qr/./>
 
 =head1 CAVEATS
 
-This module intentially ignores the B<BSDPAN> hack on FreeBSD -- the
+This module intentionally ignores the B<BSDPAN> hack on FreeBSD -- the
 additional directory is removed from C<@INC> altogether.
 
 The static-scanning heuristic is not likely to be 100% accurate, especially
@@ -219,12 +219,14 @@ But this one does not:
 =cut
 
 my $SeenTk;
+my %SeenRuntimeLoader;
 
 # Pre-loaded module dependencies {{{
 my %Preload;
 %Preload = (
     'AnyDBM_File.pm'  => [qw( SDBM_File.pm )],
     'Authen/SASL.pm'  => 'sub',
+    'B/Hooks/EndOfScope.pm' => [qw( B/Hooks/EndOfScope/PP.pm B/Hooks/EndOfScope/XS.pm )],
     'Bio/AlignIO.pm'  => 'sub',
     'Bio/Assembly/IO.pm'  => 'sub',
     'Bio/Biblio/IO.pm'  => 'sub',
@@ -256,7 +258,10 @@ my %Preload;
     'Catalyst/Engine.pm' => 'sub',
     'CGI/Application/Plugin/Authentication.pm' => [qw( CGI/Application/Plugin/Authentication/Store/Cookie.pm )],
     'CGI/Application/Plugin/AutoRunmode.pm' => [qw( Attribute/Handlers.pm )],
-
+    'charnames.pm' => sub {
+        _find_in_inc('unicore/Name.pl') ? 'unicore/Name.pl' : 'unicode/Name.pl'
+    },
+    'Class/Load.pm' => [qw( Class/Load/PP.pm )],
     'Class/MakeMethods.pm' => 'sub',
     'Class/MethodMaker.pm' => 'sub',
     'Config/Any.pm' =>'sub',
@@ -274,6 +279,7 @@ my %Preload;
         return (_glob_in_inc('Date/Manip/TZ', 1),
                 _glob_in_inc('Date/Manip/Offset', 1));
     },
+    'DateTime/Format/Builder/Parser.pm' => 'sub',
     'DateTime/Locale.pm' => 'sub',
     'DateTime/TimeZone.pm' => 'sub',
     'DBI.pm' => sub {
@@ -287,6 +293,37 @@ my %Preload;
     'Device/SerialPort.pm' => [ qw(
         termios.ph asm/termios.ph sys/termiox.ph sys/termios.ph sys/ttycom.ph
     ) ],
+    'diagnostics.pm' => sub {
+        # shamelessly taken and adapted from diagnostics.pm
+        use Config;
+        my($privlib, $archlib) = @Config{qw(privlibexp archlibexp)};
+        if ($^O eq 'VMS') {
+            require VMS::Filespec;
+            $privlib = VMS::Filespec::unixify($privlib);
+            $archlib = VMS::Filespec::unixify($archlib);
+        }
+
+        for (
+              "pod/perldiag.pod",
+              "Pod/perldiag.pod",
+              "pod/perldiag-$Config{version}.pod",
+              "Pod/perldiag-$Config{version}.pod",
+              "pods/perldiag.pod",
+              "pods/perldiag-$Config{version}.pod",
+        ) {
+            return $_ if _find_in_inc($_);
+        }
+        
+        for (
+              "$archlib/pods/perldiag.pod",
+              "$privlib/pods/perldiag-$Config{version}.pod",
+              "$privlib/pods/perldiag.pod",
+        ) {
+            return $_ if -f $_;
+        }
+
+        return 'pod/perldiag.pod';
+    },
     'Email/Send.pm' => 'sub',
     'Event.pm' => [ map "Event/$_.pm", qw(idle io signal timer var)],
     'ExtUtils/MakeMaker.pm' => sub {
@@ -325,16 +362,11 @@ my %Preload;
         # but accept JSON::XS, too (because JSON.pm might use it if present)
         return( grep /^JSON\/(PP|XS)/, _glob_in_inc('JSON', 1) );
     },
-    'Log/Log4perl.pm' => 'sub',
+    'Locale/Maketext/Lexicon.pm'    => 'sub',
+    'Locale/Maketext/GutsLoader.pm' => [qw( Locale/Maketext/Guts.pm )],
     'Log/Any.pm' => 'sub',
+    'Log/Log4perl.pm' => 'sub',
     'Log/Report/Dispatcher.pm' => 'sub',
-    'LWP/UserAgent.pm' => sub {
-        return( 
-          qw( URI/URL.pm URI/http.pm LWP/Protocol/http.pm ),
-          _glob_in_inc("LWP/Authen", 1),
-          _glob_in_inc("LWP/Protocol", 1),
-        );
-    },
     'LWP/Parallel.pm' => sub {
         _glob_in_inc( 'LWP/Parallel', 1 ),
         qw(
@@ -346,17 +378,22 @@ my %Preload;
         qw( LWP/Parallel.pm ),
         @{ _get_preload('LWP/Parallel.pm') }
     },
-    'Locale/Maketext/Lexicon.pm'    => 'sub',
-    'Locale/Maketext/GutsLoader.pm' => [qw( Locale/Maketext/Guts.pm )],
+    'LWP/UserAgent.pm' => sub {
+        return( 
+          qw( URI/URL.pm URI/http.pm LWP/Protocol/http.pm ),
+          _glob_in_inc("LWP/Authen", 1),
+          _glob_in_inc("LWP/Protocol", 1),
+        );
+    },
     'Mail/Audit.pm'                => 'sub',
     'Math/BigInt.pm'                => 'sub',
     'Math/BigFloat.pm'              => 'sub',
     'Math/Symbolic.pm'              => 'sub',
+    'MIME/Decoder.pm'               => 'sub',
     'Module/Build.pm'               => 'sub',
     'Module/Pluggable.pm'           => sub {
         _glob_in_inc('$CurrentPackage/Plugin', 1);
     },
-    'MIME/Decoder.pm'               => 'sub',
     'Moose.pm'                      => sub {
         _glob_in_inc('Moose', 1),
         _glob_in_inc('Class/MOP', 1),
@@ -370,23 +407,30 @@ my %Preload;
         qw( MozRepl/Log.pm MozRepl/Client.pm Module/Pluggable/Fast.pm ),
         _glob_in_inc('MozRepl/Plugin', 1),
     },
+    'Module/Implementation.pm'      => \&_warn_of_runtime_loader,
+    'Module/Runtime.pm'             => \&_warn_of_runtime_loader,
     'Net/DNS/RR.pm'                 => 'sub',
     'Net/FTP.pm'                    => 'sub',
+    'Net/HTTPS.pm'                  => [qw( IO/Socket/SSL.pm Net/SSL.pm )],
     'Net/Server.pm'                 => 'sub',
     'Net/SSH/Perl.pm'               => 'sub',
     'Package/Stash.pm'              => [qw( Package/Stash/PP.pm Package/Stash/XS.pm )],
     'Pango.pm'                      => [qw( Cairo.pm )], # Pango.pm does: eval "use Cairo;"
     'PAR/Repository.pm'             => 'sub',
     'PAR/Repository/Client.pm'      => 'sub',
+    'Params/Validate.pm'            => 'sub',
     'Parse/AFP.pm'                  => 'sub',
     'Parse/Binary.pm'               => 'sub',
-    'Perl/Critic.pm'                => 'sub', #not only Perl/Critic/Policy
-    'PerlIO.pm'                     => [ 'PerlIO/scalar.pm' ],
     'PDF/API2/Resource/Font.pm'     => 'sub',
     'PDF/API2/Basic/TTF/Font.pm'    => sub {
         _glob_in_inc('PDF/API2/Basic/TTF', 1);
     },
     'PDF/Writer.pm'                 => 'sub',
+    'Perl/Critic.pm'                => 'sub', #not only Perl/Critic/Policy
+    'PerlIO.pm'                     => [ 'PerlIO/scalar.pm' ],
+    'Pod/Usage.pm'                  => sub {  # from Pod::Usage (as of 1.61)
+         $] >= 5.005_58 ? 'Pod/Text.pm' : 'Pod/PlainText.pm'
+     },
     'POE.pm'                        => [qw( POE/Kernel.pm POE/Session.pm )],
     'POE/Component/Client/HTTP.pm'  => sub {
         _glob_in_inc('POE/Component/Client/HTTP', 1),
@@ -423,6 +467,7 @@ my %Preload;
     'SQL/Translator/Schema.pm' => sub {
         _glob_in_inc('SQL/Translator', 1);
     },
+    'Sub/Exporter/Progressive.pm'   => [qw( Sub/Exporter.pm )],
     'SVK/Command.pm' => sub {
         _glob_in_inc('SVK', 1);
     },
@@ -433,6 +478,9 @@ my %Preload;
     'Template.pm'      => 'sub',
     'Term/ReadLine.pm' => 'sub',
     'Test/Deep.pm'     => 'sub',
+    'threads/shared.pm' => [qw( attributes.pm )],
+    # anybody using threads::shared is likely to declare variables
+    # with attribute :shared
     'Tk.pm'            => sub {
         $SeenTk = 1;
         qw( Tk/FileSelect.pm Encode/Unicode.pm );
@@ -454,6 +502,11 @@ my %Preload;
     'URI.pm'            => sub {
         grep !/urn/, _glob_in_inc('URI', 1);
     },
+    'utf8.pm' => sub {
+        # Perl 5.6.x: "unicode", Perl 5.8.x and up: "unicore"
+        my $unicore = _find_in_inc('unicore/Name.pl') ? 'unicore' : 'unicode';
+        return ('utf8_heavy.pl', map $_->{name}, _glob_in_inc($unicore, 0));
+    },
     'Win32/EventLog.pm'    => [qw( Win32/IPC.pm )],
     'Win32/Exe.pm'         => 'sub',
     'Win32/TieRegistry.pm' => [qw( Win32API/Registry.pm )],
@@ -470,48 +523,16 @@ my %Preload;
     'XMLRPC/Lite.pm' => sub {
         _glob_in_inc('XMLRPC/Transport', 1),;
     },
-    'YAML.pm' => [qw( YAML/Loader.pm YAML/Dumper.pm )],
-    'diagnostics.pm' => sub {
-        # shamelessly taken and adapted from diagnostics.pm
-        use Config;
-        my($privlib, $archlib) = @Config{qw(privlibexp archlibexp)};
-        if ($^O eq 'VMS') {
-            require VMS::Filespec;
-            $privlib = VMS::Filespec::unixify($privlib);
-            $archlib = VMS::Filespec::unixify($archlib);
+    'YAML.pm'           => [qw( YAML/Loader.pm YAML/Dumper.pm )],
+    'YAML/Any.pm'       => sub { 
+        # try to figure out what YAML::Any would have used
+        my $impl = eval "use YAML::Any; YAML::Any->implementation;";
+        unless ($@) 
+        { 
+            $impl =~ s!::!/!g; 
+            return "$impl.pm"; 
         }
-
-        for (
-              "pod/perldiag.pod",
-              "Pod/perldiag.pod",
-              "pod/perldiag-$Config{version}.pod",
-              "Pod/perldiag-$Config{version}.pod",
-              "pods/perldiag.pod",
-              "pods/perldiag-$Config{version}.pod",
-        ) {
-            return $_ if _find_in_inc($_);
-        }
-        
-        for (
-              "$archlib/pods/perldiag.pod",
-              "$privlib/pods/perldiag-$Config{version}.pod",
-              "$privlib/pods/perldiag.pod",
-        ) {
-            return $_ if -f $_;
-        }
-
-        return 'pod/perldiag.pod';
-    },
-    'threads/shared.pm' => [qw( attributes.pm )],
-    # anybody using threads::shared is likely to declare variables
-    # with attribute :shared
-    'utf8.pm' => sub {
-        # Perl 5.6.x: "unicode", Perl 5.8.x and up: "unicore"
-        my $unicore = _find_in_inc('unicore/Name.pl') ? 'unicore' : 'unicode';
-        return ('utf8_heavy.pl', map $_->{name}, _glob_in_inc($unicore, 0));
-    },
-    'charnames.pm' => sub {
-        _find_in_inc('unicore/Name.pl') ? 'unicore/Name.pl' : 'unicode/Name.pl'
+        _glob_in_inc('YAML', 1);        # fallback
     },
 );
 
@@ -524,8 +545,8 @@ sub path_to_inc_name($$) {
 
     if ($path =~ m/\.pm$/io) {
         die "$path doesn't exist" unless (-f $path);
-        my $module_info = Module::Build::ModuleInfo->new_from_file($path);
-        die "Module::Build::ModuleInfo error: $!" unless defined($module_info);
+        my $module_info = Module::Metadata->new_from_file($path);
+        die "Module::Metadata error: $!" unless defined($module_info);
         $inc_name = $module_info->name();
         if (defined($inc_name)) {
             $inc_name =~ s|\:\:|\/|og;
@@ -713,32 +734,26 @@ sub scan_deps_runtime {
 
     $files = (ref($files)) ? $files : [$files];
 
-    my ($inchash, $incarray, $dl_shared_objects) = ({}, [], []);
     if ($compile) {
-        my $file;
-
-        foreach $file (@$files) {
+        foreach my $file (@$files) {
             next unless $file =~ $ScanFileRE;
 
-            ($inchash, $dl_shared_objects, $incarray) = ({}, [], []);
-            _compile_or_execute($compile, $perl, $file, $inchash, $dl_shared_objects, $incarray);
+            my ($inchash, $dl_shared_objects, $incarray) = ({}, [], []);
+            _compile_or_execute($perl, $file, undef,
+                                $inchash, $dl_shared_objects, $incarray);
 
-            my $rv_sub = _make_rv($inchash, $dl_shared_objects, $incarray);
-            _merge_rv($rv_sub, $rv);
+            _merge_rv(_make_rv($inchash, $dl_shared_objects, $incarray), $rv);
         }
     }
     elsif ($execute) {
-        my $excarray = (ref($execute)) ? $execute : [@$files];
-        my $exc;
-        foreach $exc (@$excarray) {
-            ($inchash, $dl_shared_objects, $incarray) = ({}, [], []);
-            _compile_or_execute($compile, $perl, $exc, $inchash, $dl_shared_objects, $incarray);
-        }
+        foreach my $file (@$files) {
+            $execute = [] unless ref $execute;  # make sure it's an array ref
+            my ($inchash, $dl_shared_objects, $incarray) = ({}, [], []);
+            _compile_or_execute($perl, $file, $execute,
+                                $inchash, $dl_shared_objects, $incarray);
 
-        # XXX only retains data from last execute ...  Why? I suspect
-        # the above loop was added later.  Needs test cases --Eric
-        my $rv_sub = _make_rv($inchash, $dl_shared_objects, $incarray);
-        _merge_rv($rv_sub, $rv);
+            _merge_rv(_make_rv($inchash, $dl_shared_objects, $incarray), $rv);
+        }
     }
 
     return ($rv);
@@ -758,22 +773,21 @@ sub scan_file{
         foreach my $pm (scan_line($line)) {
             last LINE if $pm eq '__END__';
 
-            # Skip Tk hits from Term::ReadLine and Tcl::Tk
-            my $pathsep = qr/\/|\\|::/;
-            if ($pm =~ /^Tk\b/) {
-                next if $file =~ /(?:^|${pathsep})Term${pathsep}ReadLine\.pm$/;
-                next if $file =~ /(?:^|${pathsep})Tcl${pathsep}Tk\W/;
-            }
             if ($pm eq '__POD__') {
                 while (<$FH>) {
                     last if (/^=cut/);
                 }
                 next LINE;
             }
+
+            # Skip Tk hits from Term::ReadLine and Tcl::Tk
+            my $pathsep = qr/\/|\\|::/;
+            if ($pm =~ /^Tk\b/) {
+                next if $file =~ /(?:^|${pathsep})Term${pathsep}ReadLine\.pm$/;
+                next if $file =~ /(?:^|${pathsep})Tcl${pathsep}Tk\W/;
+            }
             $SeenTk || do{$SeenTk = 1 if $pm =~ /Tk\.pm$/;};
-            # the following line does not make much sense here ???
-            # $file is an absolute path and will never match
-            #$pm = 'CGI/Apache.pm' if $file =~ /^Apache(?:\.pm)$/;
+
             $found{$pm}++;
         }
     }
@@ -808,11 +822,38 @@ sub scan_line {
           }
         }
 
-        if (my ($autouse) = /^use \s+ autouse \s+ (["'].*?["']|\w+)/x)
+        if (my ($pragma, $args) = /^use \s+ (autouse|if) \s+ (.+)/x)
         {
-            $autouse =~ s/["']//g;
-            $autouse =~ s{::}{/}g;
-            return ("autouse.pm", "$autouse.pm");
+            # NOTE: There are different ways the MODULE may
+            # be specified for the "autouse" and "if" pragmas, e.g.
+            #   use autouse Module => qw(func1 func2);
+            #   use autouse "Module", qw(func1);
+            # To avoid to parse them ourself, we simply try to eval the 
+            # string after the pragma (in a list context). The MODULE
+            # should be the first ("autouse") or second ("if") element
+            # of the list.
+            my $module;
+            { 
+                no strict; no warnings; 
+                if ($pragma eq "autouse") {
+                    ($module) = eval $args;
+                }
+                else {
+                    # The syntax of the "if" pragma is
+                    #   use if COND, MODULE => ARGUMENTS
+                    # The COND may contain undefined functions (i.e. undefined
+                    # in Module::ScanDeps' context) which would throw an 
+                    # exception. Sneak  "1 || " in front of COND so that
+                    # COND will not be evaluated. This will work in most
+                    # cases, but there are operators with lower precedence
+                    # than "||" which will cause this trick to fail.
+                    (undef, $module) = eval "1 || $args";
+                }
+                # punt if there was a syntax error
+                return if $@ or !defined $module;
+            };
+            $module =~ s{::}{/}g;
+            return ("$pragma.pm", "$module.pm");
         }
 
         if (my ($how, $libs) = /^(use \s+ lib \s+ | (?:unshift|push) \s+ \@INC \s+ ,) (.+)/x)
@@ -879,7 +920,7 @@ sub scan_chunk {
 
         # TODO: There's many more of these "loader" type modules on CPAN!
         # scan for the typical module-loader modules
-        my $loaders = "asa base parent prefork POE encoding maybe only::matching";
+        my $loaders = "asa base parent prefork POE encoding maybe only::matching Mojo::Base";
         # grab pre-calculated regexp or re-build it (and cache it)
         my $loader_regexp = $LoaderRegexp{$loaders} || _build_loader_regexp($loaders);
         if ($_ =~ $loader_regexp) { # $1 == loader, $2 == loadee
@@ -913,18 +954,22 @@ sub scan_chunk {
             my $diamond = $1;
             return "File/Glob.pm" if $diamond =~ /[*?\[\]{}~\\]/;
         }
+
         return "DBD/$1.pm"    if /\b[Dd][Bb][Ii]:(\w+):/;
-        if (/(?:(:encoding)|\b(?:en|de)code)\(\s*['"]?([-\w]+)/) {
-            my $mod = _find_encoding($2);
-            my @mods = ( 'Encoding.pm' );       # always needed
-            push @mods, 'PerlIO.pm' if $1;      # needed for ":encoding(...)"
+
+        # check for stuff like
+        #   decode("klingon", ...)
+        #   open FH, "<:encoding(klingon)", ...
+        if (my ($io_layer, $encoding) = /(?:(:encoding)|\b(?:en|de)code)\(\s*['"]?([-\w]+)/) {
+            my @mods;
+            my $mod = _find_encoding($encoding);
             push @mods, $mod if $mod;           # "external" Encode module
+            push @mods, qw( PerlIO.pm PerlIO/encoding.pm ) if $io_layer;
             return \@mods;
         }
+
         return $1 if /^(?:do|require)\s+[^"]*"(.*?)"/;
         return $1 if /^(?:do|require)\s+[^']*'(.*?)'/;
-        return $1 if /[^\$]\b([\w:]+)->\w/ and $1 ne 'Tk' and $1 ne 'shift';
-        return $1 if /\b(\w[\w:]*)::\w+\(/ and $1 ne 'main' and $1 ne 'SUPER';
 
         if ($SeenTk) {
             my @modules;
@@ -945,6 +990,13 @@ sub scan_chunk {
             }
             return \@modules;
         }
+
+        # Module::Runtime
+        return $1 if /\b(?:require_module|use_module|use_package_optimistically) \s* \( \s* ([\w:"']+)/x;
+
+        # Test::More
+        return $1 if /\b(?:require_ok|use_ok) \s* \( \s* ([\w:"']+)/x;
+
         return;
     };
 
@@ -1072,7 +1124,7 @@ sub add_deps {
                            type   => $type );
             }
 
-            ### Now, handle module and distribudion share dirs
+            ### Now, handle module and distribution share dirs
             # convert 'Module/Name' to 'Module-Name'
             my $modname = $path;
             $modname =~ s|/|-|g;
@@ -1234,8 +1286,10 @@ sub get_files {
 
 # scan_deps_runtime utility functions
 
+# compile $file if $execute is undef,
+# otherwise execute $file with arguments @$execute
 sub _compile_or_execute {
-    my ($compile, $perl, $file, $inchash, $dl_shared_objects, $incarray) = @_;
+    my ($perl, $file, $execute, $inchash, $dl_shared_objects, $incarray) = @_;
 
     require Module::ScanDeps::DataFeed; 
     # ... so we can find it's full pathname in %INC
@@ -1254,7 +1308,7 @@ sub _compile_or_execute {
                    "*0 = \\\$Module::ScanDeps::DataFeed::_0;\n",
                    "}\n";
 
-    print $feed_fh $compile ? "CHECK {\n" : "END {\n";
+    print $feed_fh $execute ? "END {\n" : "CHECK {\n" ;
     # NOTE: When compiling the block will run as the last CHECK block;
     # when executing the block will run as the first END block and 
     # the programs continues.
@@ -1264,7 +1318,7 @@ sub _compile_or_execute {
                        [ $INC{"Module/ScanDeps/DataFeed.pm"}, $dump_file ],
                        [ qw( datafeedpm dump_file ) ]);
 
-    # save %INC etc so that further requires dont't pollute them
+    # save %INC etc so that further requires don't pollute them
     print $feed_fh <<'...';
     %Module::ScanDeps::DataFeed::_INC = %INC;
     @Module::ScanDeps::DataFeed::_INC = @INC;
@@ -1277,7 +1331,7 @@ sub _compile_or_execute {
 }
 ...
 
-    # append the file to compile
+    # append the file to compile or execute
     {
         open my $fhin, "<", $file or die "Couldn't open $file: $!";
         print $feed_fh qq[#line 1 "$file"\n], <$fhin>;
@@ -1288,16 +1342,18 @@ sub _compile_or_execute {
     File::Path::rmtree( ['_Inline'], 0, 1); # XXX hack
     
     my @cmd = ($perl);
-    push @cmd, "-c" if $compile;
+    push @cmd, "-c" unless $execute;
     push @cmd, map { "-I$_" } @IncludeLibs;
-    my $rc = system(@cmd, $feed_file);
+    push @cmd, $feed_file;
+    push @cmd, @$execute if $execute;
+    my $rc = system(@cmd);
 
     _extract_info($dump_file, $inchash, $dl_shared_objects, $incarray) 
         if $rc == 0;
     unlink($feed_file, $dump_file);
-    die $compile
-        ? "SYSTEM ERROR in compiling $file: $rc" 
-        : "SYSTEM ERROR in executing $file: $rc" 
+    die $execute
+        ? "SYSTEM ERROR in executing $file @$execute: $rc" 
+        : "SYSTEM ERROR in compiling $file: $rc" 
         unless $rc == 0;
 }
 
@@ -1424,6 +1480,15 @@ sub _abs_path {
 }
 
 
+sub _warn_of_runtime_loader {
+    my $module = shift;
+    return if $SeenRuntimeLoader{$module}++;
+    $module =~ s/\.pm$//;
+    $module =~ s|/|::|g;
+    warn "# Use of runtime loader module $module detected.  Results of static scanning may be incomplete.\n";
+    return;
+}
+
 sub _warn_of_missing_module {
     my $module = shift;
     my $warn = shift;
